==> flink-1.19.3-src.tgz: flink-1.19.3/flink-runtime-web/web-dashboard/src/app/components/addon-inline/addon-inline.component.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { NgIf } from '@angular/common';
import { Component, ChangeDetectionStrategy, Input, Output, EventEmitter } from '@angular/core';

import { NzDividerModule } from 'ng-zorro-antd/divider';
import { NzIconModule } from 'ng-zorro-antd/icon';

@Component({
  selector: 'flink-addon-inline',
  templateUrl: './addon-inline.component.html',
  styleUrls: ['./addon-inline.component.less'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  imports: [NgIf, NzIconModule, NzDividerModule],
  standalone: true
})
export class AddonInlineComponent {
  @Input() downloadName: string;
  @Input() downloadHref: string;
  @Input() isLoading = false;
  @Output() reload = new EventEmitter<void>();
  @Output() fullScreen = new EventEmitter<boolean>();
  isFullScreen = false;

  toggleFullScreen(): void {
    this.isFullScreen = !this.isFullScreen;
    this.fullScreen.emit(this.isFullScreen);
  }
}

==> flink-2.2.0-src.tgz: flink-2.2.0/flink-runtime-web/web-dashboard/src/app/components/addon-inline/addon-inline.component.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { NgIf } from '@angular/common';
import { Component, ChangeDetectionStrategy, Input, Output, EventEmitter } from '@angular/core';

import { NzDividerModule } from 'ng-zorro-antd/divider';
import { NzIconModule } from 'ng-zorro-antd/icon';

@Component({
  selector: 'flink-addon-inline',
  templateUrl: './addon-inline.component.html',
  styleUrls: ['./addon-inline.component.less'],
  changeDetection: ChangeDetectionStrategy.OnPush,
  imports: [NgIf, NzIconModule, NzDividerModule]
})
export class AddonInlineComponent {
  @Input() downloadName: string;
  @Input() downloadHref: string;
  @Input() isLoading = false;
  @Output() reload = new EventEmitter<void>();
  @Output() fullScreen = new EventEmitter<boolean>();
  isFullScreen = false;

  toggleFullScreen(): void {
    this.isFullScreen = !this.isFullScreen;
    this.fullScreen.emit(this.isFullScreen);
  }
}
